FormModel class

Constructors

FormModel(String type, {GlobalKey<FormFieldState>? key, bool? required, String? requiredError, FormFieldValidator<String>? validator, String? dataField, dynamic value})

Properties

dataField → String?
final
hashCode → int
The hash code for this object.
no setterinherited
key → GlobalKey<FormFieldState>
final
required → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final
validator → FormFieldValidator<String>?
final
value → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

requiredValidator(String? requiredError) → String? Function(String?)?